delp: p-value arrangement

Description Usage Arguments Details Value Author(s)

View source: R/Mixed_Kernel_Interaction_package.R

Description

delp is used to organize the p-values which are obtained from multiple testing adjustment.

Usage

1
delp(x)

Arguments

x

p-values matrix obtained from multiple testing adjustment.

Details

If w p-values are all equal to 1 in a variable, then they are not combined by Cauchy. Their combination is 1. If w p-values are all less than 1, then they are combined by Cauchy. If part of p-values are less then 1 and the others are equal to 1, then we just use Cauchy to combine the ones less than 1.

Value

out

Author(s)

Yan Liu


wsly850707/mixed-kernel-package documentation built on Dec. 23, 2021, 6:12 p.m.