mta: multiple testing adjustment

Description Usage Arguments Value Author(s) References

View source: R/Mixed_Kernel_Interaction_package.R

Description

mta is used to adjust the p-values obtained from multiple tests.

Usage

1
mta(x)

Arguments

x

main and interaction effects matrix that is used to HDI.

Value

sum.fx

effective number of independent tests

Author(s)

Yan Liu

References

Li J, Ji L. Adjusting multiple testing in multilocus analyses using the eigenvalues of a correlation matrix. Heredity (Edinb). 2005; 95:221-227.


wsly850707/mixed-kernel-package documentation built on Dec. 23, 2021, 6:12 p.m.