Description Usage Arguments Value Author(s) References
View source: R/Mixed_Kernel_Interaction_package.R
mta is used to adjust the p-values obtained from multiple tests.
1 | mta(x)
|
x |
main and interaction effects matrix that is used to HDI. |
sum.fx |
effective number of independent tests |
Yan Liu
Li J, Ji L. Adjusting multiple testing in multilocus analyses using the eigenvalues of a correlation matrix. Heredity (Edinb). 2005; 95:221-227.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.